import React from 'react'
import PropTypes from 'prop-types'
import Logo from 'rsg-components/Logo'
import StyleguideFooter from 'rsg-components/StyleguideFooter'
import Styled from 'rsg-components/Styled'
import cx from 'classnames'
import Ribbon from 'rsg-components/Ribbon'
import Version from 'rsg-components/Version'
import consts from '../../../scripts/consts'

const styles = ({ color, sidebarWidth, mq, space, maxWidth }) => ({
	root: {
		minHeight: '100vh',
		backgroundColor: color.baseBackground
	},
	hasSidebar: {
		paddingLeft: sidebarWidth,
		[mq.small]: {
			paddingLeft: 0
		}
	},
	content: {
		maxWidth,
		padding: [[space[2], space[4]]],
		margin: [[0, 'auto']],
		[mq.small]: {
			padding: space[2]
		},
		display: 'block'
	},
	sidebar: {
		backgroundColor: color.sidebarBackground,
		border: [[color.border, 'solid']],
		borderWidth: [[0, 1, 0, 0]],
		position: 'fixed',
		top: 0,
		left: 0,
		bottom: 0,
		width: sidebarWidth,
		overflow: 'auto',
		'-webkit-overflow-scrolling': 'touch',
		[mq.small]: {
			position: 'static',
			width: 'auto',
			borderWidth: [[1, 0, 0, 0]],
			paddingBottom: space[0]
		}
	},
	logo: {
		padding: space[2],
		borderBottom: [[1, color.border, 'solid']]
	}
})

export function StyleGuideRenderer({ classes, title, version, children, toc, hasSidebar }) {
	return (
		<div className={cx(classes.root, hasSidebar && classes.hasSidebar)}>
			<main className={classes.content}>
				{children}
				<StyleguideFooter homepageUrl={consts.HOMEPAGE} />
			</main>
			{hasSidebar && (
				<div className={classes.sidebar}>
					<div className={classes.logo}>
						<Logo>{title}</Logo>
						{version && <Version>{version}</Version>}
					</div>
					{toc}
				</div>
			)}
			<Ribbon />
		</div>
	)
}

StyleGuideRenderer.propTypes = {
	classes: PropTypes.object.isRequired,
	title: PropTypes.string.isRequired,
	version: PropTypes.string,
	homepageUrl: PropTypes.string.isRequired,
	children: PropTypes.node.isRequired,
	toc: PropTypes.node.isRequired,
	hasSidebar: PropTypes.bool
}

export default Styled(styles)(StyleGuideRenderer)
